summaryrefslogtreecommitdiff
path: root/telepathy-glib/contact.c
diff options
context:
space:
mode:
authorSimon McVittie <simon.mcvittie@collabora.co.uk>2012-05-03 13:06:17 +0100
committerSimon McVittie <simon.mcvittie@collabora.co.uk>2012-05-03 13:06:17 +0100
commitd23ad5d02837f526d9ba804e7fb664725151a8b4 (patch)
treef7743d3f2093c5072914034eef8077ce823804c3 /telepathy-glib/contact.c
parentaa611fb0084b0c94f5e3b3c9c7e5ae30b8556c67 (diff)
parent59e580c564711b194d3c0c8004cf8db195f06428 (diff)
downloadtelepathy-glib-d23ad5d02837f526d9ba804e7fb664725151a8b4.tar.gz
Merge branch 'deprecation'
Reviewed-by: Xavier Claessens <xavier.claessens@collabora.co.uk> Bug: https://bugs.freedesktop.org/show_bug.cgi?id=49400
Diffstat (limited to 'telepathy-glib/contact.c')
-rw-r--r--telepathy-glib/contact.c12
1 files changed, 6 insertions, 6 deletions
diff --git a/telepathy-glib/contact.c b/telepathy-glib/contact.c
index 352113722..ff6843ca0 100644
--- a/telepathy-glib/contact.c
+++ b/telepathy-glib/contact.c
@@ -1853,7 +1853,7 @@ contacts_context_fail (ContactsContext *c,
* @contacts will contain contact objects for those IDs that were
* valid (it may be empty), and @failed_id_errors will map the IDs
* that were not valid to a corresponding #GError (if the connection manager
* complies with the Telepathy spec, it will have domain %TP_ERRORS and code
* %TP_ERROR_INVALID_HANDLE).
*
* If an unrecoverable error occurs (for instance, if @connection
@@ -1993,7 +1993,7 @@ contacts_held_one (TpConnection *connection,
g_ptr_array_add (c->contacts, contact);
c->next_index++;
}
- else if (error->domain == TP_ERRORS &&
+ else if (error->domain == TP_ERROR &&
error->code == TP_ERROR_INVALID_HANDLE)
{
g_array_append_val (c->invalid,
@@ -2055,7 +2055,7 @@ contacts_held_handles (TpConnection *connection,
g_array_index (c->handles, TpHandle, i)));
}
}
- else if (error->domain == TP_ERRORS &&
+ else if (error->domain == TP_ERROR &&
error->code == TP_ERROR_INVALID_HANDLE)
{
/* One of the handles is bad. We don't know which one :-( so split
@@ -2260,7 +2260,7 @@ contacts_got_aliases (TpConnection *connection,
g_object_notify ((GObject *) contact, "alias");
}
}
- else if ((error->domain == TP_ERRORS &&
+ else if ((error->domain == TP_ERROR &&
error->code == TP_ERROR_NOT_IMPLEMENTED) ||
(error->domain == DBUS_GERROR &&
error->code == DBUS_GERROR_UNKNOWN_METHOD))
@@ -4419,7 +4419,7 @@ contacts_requested_one_handle (TpConnection *connection,
g_ptr_array_add (c->contacts, contact);
c->next_index++;
}
- else if (error->domain == TP_ERRORS &&
+ else if (error->domain == TP_ERROR &&
(error->code == TP_ERROR_INVALID_HANDLE ||
error->code == TP_ERROR_NOT_AVAILABLE ||
error->code == TP_ERROR_INVALID_ARGUMENT))
@@ -4483,7 +4483,7 @@ contacts_requested_handles (TpConnection *connection,
g_ptr_array_add (c->contacts, contact);
}
}
- else if (error->domain == TP_ERRORS &&
+ else if (error->domain == TP_ERROR &&
(error->code == TP_ERROR_INVALID_HANDLE ||
error->code == TP_ERROR_NOT_AVAILABLE ||
error->code == TP_ERROR_INVALID_ARGUMENT))
@@ -1853,7 +1853,7 @@ contacts_context_fail (ContactsContext *c,
* valid (it may be empty), and @failed_id_errors will map the IDs
* that were not valid to a corresponding #GError (if the connection manager
- * complies with the Telepathy spec, it will have domain %TP_ERRORS and code
+ * complies with the Telepathy spec, it will have domain %TP_ERROR and code
* %TP_ERROR_INVALID_HANDLE).
*